@@ -1,13 +1,13 @@
 //! Contains convenience wrappers for argument parsing using Clap
 #![deny(missing_docs)] // All commands must have help/about statements
 
-use clap::{AppSettings, Parser, Subcommand};
+use clap::{Parser, Subcommand};
 use std::path::PathBuf;
 
 #[derive(Parser)]
 #[clap(author, version, about)]
-#[clap(global_setting(AppSettings::PropagateVersion))]
-#[clap(setting(AppSettings::SubcommandRequiredElseHelp))]
+#[clap(propagate_version = true)]
+#[clap(subcommand_required = true)]
 pub struct Ferium {
 	#[clap(subcommand)]
 	pub subcommand: SubCommands,
@@ -32,9 +32,13 @@ pub enum SubCommands {
 		#[clap(help("The project ID is specified as 'Project ID' in the 'About Project' sidebar of the mod's CurseForge page"))]
 		project_id: i32,
 	},
-	#[clap(about("List all the mods in the profile with some their metadata"))]
-	List,
-	#[clap(setting(AppSettings::SubcommandRequiredElseHelp))]
+	#[clap(about("List all the mods in the profile, and with some their metadata if verbose"))]
+	List {
+		#[clap(long, short)]
+		#[clap(help("Show information about the mod"))]
+		verbose: bool,
+	},
+	#[clap(subcommand_required = true)]
 	#[clap(about("Create, configure, or remove the current profile"))]
 	Profile {
 		#[clap(subcommand)]
@@ -57,12 +61,9 @@ pub enum SubCommands {
 	Upgrade {
 		#[clap(long)]
 		#[clap(help(
-			"Do not show a picker when multiple compatible assets are found and pick the first one"
-		))]
-		no_picker: bool,
-		#[clap(long)]
-		#[clap(help(
-			"Do not check for the full game version, only check for the major and minor versions"
+			"Do not check for the full game version, only check for the major and minor versions
+			\rSome Minecraft versions (e.g. 1.18 & 1.18.1) are compatible with each other,
+			\rthis option allows you to use older, but still compatible, versions of a mod that might not have yet updated to the latest version"
 		))]
 		no_patch_check: bool,
 	},
